@@ -3,32 +3,43 @@ from os import environ
 import json
 import http.client
 
+# custom exceptions
+class ContentAIError(Exception):
+    """ represents a contentai error """
+    pass
+
 # environment variables
+
 # The job_id given to this dag by the ContentAI Platform
-job_id = os.environ["EXTRACTOR_JOB_ID"]
+job_id = os.getenv("EXTRACTOR_JOB_ID", "")
 
 # The location of the asset you wish to perform inference on
-content_url = os.environ["EXTRACTOR_CONTENT_URL"]
+content_url = os.getenv("EXTRACTOR_CONTENT_URL", "")
 
 # when you download the content (download_content())
 # you can access the artifact at content_url
-content_path = os.environ["EXTRACTOR_CONTENT_PATH"]
+content_path = os.getenv("EXTRACTOR_CONTENT_PATH", "")
 
 # write results to this location which you want saved to the Data Lake
-result_path = os.environ["EXTRACTOR_RESULT_PATH"]
+result_path = os.getenv("EXTRACTOR_RESULT_PATH", "")
 
 # get extractor name
-extractor_name = os.environ["EXTRACTOR_NAME"]
+extractor_name = os.getenv("EXTRACTOR_NAME", "")
 
 # json supplied to this job
-if environ.get("EXTRACTOR_METADATA") is not None:
-    metadata_json = os.environ["EXTRACTOR_METADATA"]
+metadata_json = os.getenv("EXTRACTOR_METADATA", None)
 
 # whether or not we're running in the platform
 running_in_contentai = False
 if "RUNNING_IN_CONTENTAI" in os.environ:
     running_in_contentai = (os.environ["RUNNING_IN_CONTENTAI"] == "true")
 
+if running_in_contentai:
+    for env_test in ["EXTRACTOR_JOB_ID", "EXTRACTOR_CONTENT_URL", "EXTRACTOR_CONTENT_PATH", 
+                     "EXTRACTOR_RESULT_PATH", "EXTRACTOR_NAME", "EXTRACTOR_METADATA"]:
+        if os.getenv(env_test) is None:
+            raise ContentAIError("The environment variable '{}' is required.".format(env_test))
+
 api_host = "127.0.0.1"
 
 # use a docker-friendly host if using the test harness
@@ -37,10 +48,6 @@ if "RUNNING_IN_TESTHARNESS" in os.environ:
         api_host = "contentai"
 
 
-class ContentAIError(Exception):
-    """ represents a contentai error """
-    pass
-
 
 def download_content():
     """ download content to work with locally
@@ -74,7 +81,7 @@ input = contentai.metadata()["input"]
 ```
     """
     result = {}
-    if metadata_json:
+    if metadata_json is not None:
         result = json.loads(metadata_json)
     return result
 
